@@ -13,7 +13,7 @@ no warnings qw( threads recursion uninitialized once redefine );
 
 package MCE::Hobo;
 
-our $VERSION = '1.831';
+our $VERSION = '1.832';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitExplicitReturnUndef)
@@ -100,7 +100,7 @@ sub init {
          $INC{'Curses.pm'} || $INC{'CGI.pm'} || $INC{'FCGI.pm'} ||
          $INC{'Prima.pm'} || $INC{'Tk.pm'} || $INC{'Wx.pm'} ||
          $INC{'Gearman/Util.pm'} || $INC{'Gearman/XS.pm'} ||
-         $INC{'Coro.pm'} || $INC{'Win32/GUI.pm'}
+         $INC{'Coro.pm'} || $INC{'stfl.pm'} || $INC{'Win32/GUI.pm'}
       );
    }
    if ( $mngd->{max_workers} ) {
@@ -204,10 +204,16 @@ sub create {
    # Sets the seed of the base generator uniquely between workers.
    # The new seed is computed using the current seed and ID value.
    # One may set the seed at the application level for predictable
-   # results. Ditto for Math::Random.
+   # results. Ditto for Math::Prime::Util and Math::Random.
 
    srand( abs($_DATA->{"$pkg:seed"} - ($id * 100000)) % 2147483560 );
 
+   if ( $INC{'Math/Prime/Util.pm'} ) {
+      Math::Prime::Util::srand(
+          abs($_DATA->{"$pkg:seed"} - ($id * 100000)) % 2147483560
+      );
+   }
+
    if ( $INC{'Math/Random.pm'} ) {
       my $cur_seed = Math::Random::random_get_seed();
       my $new_seed = ($cur_seed < 1073741781)
@@ -769,7 +775,7 @@ MCE::Hobo - A threads-like parallelization module
 
 =head1 VERSION
 
-This document describes MCE::Hobo version 1.831
+This document describes MCE::Hobo version 1.832
 
 =head1 SYNOPSIS
 
@@ -1081,7 +1087,7 @@ terminate after some time. The default is C<0> for no timeout.
 
 Set C<posix_exit> to avoid all END and destructor processing. Constructing
 MCE::Hobo inside a thread implies 1 or if present CGI, FCGI, Coro, Curses,
-Gearman::Util, Gearman::XS, Mojo::IOLoop, Prima, Tk, Wx, or Win32::GUI.
+Gearman::Util, Gearman::XS, Mojo::IOLoop, Prima, STFL, Tk, Wx, or Win32::GUI.
 
 The callback options C<on_start> and C<on_finish> are called in the parent
 process after starting a Hobo and later when terminated. The arguments
